function f = det_Q(omega, d)
    % Last modifications on 08.02.2024 by Maximilian Frenzel
    % Input: 1) omega - Angular frequency [2*pi*Hz]; 
    % 2) d - z-cut quartz crystal thickness (m)
    % Output: complex quartz detector response function for all omega
    
    Omega = transpose(omega);

    % Some constants that will be used:
    c0=299792458; % speed of light

    % Setting up the sampling pulse: modifications of sampling pulse
    % (e.g. pulse duration, central frequency) can be set in "E_vis.m"
    omega1 = 2*pi*c0/950e-9;
    omega2 = 2*pi*c0/650e-9;
    omega =(omega1:(omega2-omega1)/300:omega2).'; % visible frequencies
    E_trans = E_vis(omega) .*t12(omega) .* exp(1i*k(omega)*d) .*t23(omega); % transmitted sampling pulse pulse

    % Setting up the THz frequencies
    Omega2 = [-Omega; Omega];     % also negative Omega required for computation

    % Calculate Chi2. Values of the TO phonon and Debye-like contribution
    % might have to be fine-tuned for your respective quartz crystal
    % material
    C = 0.15; % Faust-Henry coefficient of the low-frequency phonon resonance
    omega_TO = 2*pi*3.86; % 2*pi*THz; Frequency of low-frequency TO phonon
    gamma_TO = 2*pi*0.09; % 2*pi*THz; Damping frequency of the low-frequency TO phonon
    B = 0.7; % Coefficient of the low-frequency Debyle-like contribution
    gamma = 2*pi*0.3; % 2*pi*THz; Damping frequency 
    chi2_e_eff = 0.20*1e-12; %  m/V
    chi2 = chi2_e_eff*(1+C*fh_oscillator(omega_TO*1e12, gamma_TO*1e12, Omega2) +B*fh_relaxation(gamma*1e12, Omega2));
    
    % Calculate THz Fabry Perot Transmission to account for internal
    % reflections
    THz_factor = factor_T_THz(Omega2,d);
    THz_factor(isnan(THz_factor))=0;

    % Compute phase mismatch and propagation 
    for j = (1:size(Omega2,1))
        dk = k(omega-Omega2(j)) +k(Omega2(j)) -k(omega); % wavevector mismatch
        h1 = (exp(+1j*dk*d)-1)./dk.* t23(omega-Omega2(j)) .*exp(1j*k(omega-Omega2(j))*d) ./k(omega)...
        .*conj(E_trans)...
        .*omega.^2 .*E_vis(omega-Omega2(j)) .*t12(omega-Omega2(j));
        g(j) = -1j/c0^2*trapz(omega,h1); % integrate over omega
    end
    
    % Combine all terms
    tmp = transpose(g).*THz_factor.*chi2;
    tmp = tmp.';
    h = (conj(tmp(1:size(Omega))) + tmp(size(Omega)+1:size(Omega2))); % account for sum and difference frequency
    
    I0 = trapz(omega, (E_trans.*conj(E_trans))); % total voltage on both diodes
    f = h / (I0); % correct for diode voltage
end

