function [t, x] = ift_eq(omega, Fx)
% [t, x] = ift_eq(omega, Fx) calculates inverse fourier transformation x(t) of spectral signal Fx(omega)
% - Fx has to be sampled on an equispaced omega mesh with spacing domega;
% - Returns [t x] where t starts at 0 (and no other multiples of 2*pi/domega)
% - Offset of omega is accounted for (in contrast to ft_eq)
% - Signal should fulfill the Nyquist condition (otherwise aliasing)
% - Basis functions are exp(-i*omega*t)/sqrt(2) (not +i)
% - If Fx is a matrix, operation is performed column-wise

[N, M] = size(Fx);           % M columns

% Calculate spacings and periodicities
domega = (omega(N) -omega(1))/(N-1); % N-1, not N!!! (see e.g. N=2)
T = 2*pi /domega;
dt = T/N; % N, not N-1!!! (t(N+1) - t(1) = T) (also: domega*dt = 2*pi/N)

% Columnwise DFT
t = (0:N-1).'*dt;
x = fft(Fx) *sqrt(2*pi)/T ; % hin-trafo mit +i statt -i
x = ndgrid(exp(-1i*omega(1)*t),1:M).*x; % accounts for offset of omega axis

% Old version (after line 16):

% % Rearrange spectrum for FFT
% Fx = [Fx(omega>=0,:); Fx(omega<0,:)];
% 
% % Columnwise DFT
% x = fft(Fx) *sqrt(2*pi)/T ; % hin-trafo mit +i statt -i
% t = (0:N-1).'*dt;
